[Openchrome-devel] xf86-video-openchrome: 2 commits - configure.ac src/via_display.c

Kevin Brace kevinbrace at kemper.freedesktop.org
Mon Jun 13 16:18:12 UTC 2016


 configure.ac      |    2 +-
 src/via_display.c |   21 ++++++++++-----------
 2 files changed, 11 insertions(+), 12 deletions(-)

New commits:
commit d234cdf68ea6a27718a948918b3075ad257e8a0f
Author: Kevin Brace <kevinbrace at gmx.com>
Date:   Mon Jun 13 11:17:23 2016 -0500

    Version bumped to 0.4.180
    
    This version fixes a regression that occurred at Version 0.4.177.
    IGA1 now works fine with 1920 horizontal (Y direction) screen
    resolution. Sorry about the inconvenience.
    
    Signed-off-by: Kevin Brace <kevinbrace at gmx.com>

diff --git a/configure.ac b/configure.ac
index 339da33..d06b965 100644
--- a/configure.ac
+++ b/configure.ac
@@ -23,7 +23,7 @@
 # Initialize Autoconf
 AC_PREREQ(2.57)
 AC_INIT([xf86-video-openchrome],
-        [0.4.179],
+        [0.4.180],
         [https://bugs.freedesktop.org/enter_bug.cgi?product=xorg&component=Driver/openchrome],
         [xf86-video-openchrome])
 
commit c1a81a30a30d5bc571d9498a52f4780713808de1
Author: Kevin Brace <kevinbrace at gmx.com>
Date:   Mon Jun 13 11:06:51 2016 -0500

    IGA1 horizontal total limit is now 4128
    
    There was a bad commit with commit c768c86. This broke the screen of
    people who used a monitor capable of 1920 X 1080 screen resolution.
    The regression is now fixed.
    
    Signed-off-by: Max Rus <off_mail at mail.ru>
    Signed-off-by: Kevin Brace <kevinbrace at gmx.com>

diff --git a/src/via_display.c b/src/via_display.c
index e58d7dc..d156121 100644
--- a/src/via_display.c
+++ b/src/via_display.c
@@ -1223,17 +1223,16 @@ viaIGA1ModeValid(ScrnInfoPtr pScrn, DisplayModePtr mode)
                         "Entered viaIGA1ModeValid.\n"));
 
     /* Note that horizontal total being written to VGA registers is
-     * shifted to the right by 3 bit positions, and then 5 is subtracted
-     * from it. Hence, to check if the screen can even be valid,
-     * opposite of that needs to happen. That being said, to check if the
-     * number is within an acceptable range, 1 is subtracted from 5, hence,
-     * 4 (5 - 1) is multiplied with 8 (i.e., 1 is shifted 3 bit positions to
-     * the left) and the resulting 32 is added to 2048 to calculate the
-     * maximum horizontal total IGA1 can handle. Ultimately, 2080 is the
-     * largest number VIA IGP's IGA1 can handle safely. This is how
-     * VIA Technologies gets to claim that IGA1 (i.e., VGA) is capable of
-     * 1920 dots in the horizontal (Y) direction. */
-    if (mode->CrtcHTotal > (2048 + ((1 << 3) * 4)))
+     * shifted to the right by 3 bit positions since only 9 bits are
+     * available, and then 5 is subtracted from it. Hence, to check if
+     * the screen can even be valid, opposite of that needs to happen.
+     * That being said, to check if the number is within an acceptable range,
+     * 1 is subtracted from 5, hence, 4 (5 - 1) is multiplied with 8 (i.e.,
+     * 1 is shifted 3 bit positions to the left), and the resulting 32 is
+     * added to 4096 (9 + 3 bits) to calculate the maximum horizontal total
+     * IGA1 can handle. Ultimately, 4128 is the largest number VIA IGP's
+     * IGA1 can handle. */
+    if (mode->CrtcHTotal > (4096 + ((1 << 3) * (5 - 1))))
         return MODE_BAD_HVALUE;
 
     if (mode->CrtcHDisplay > 2048)


More information about the Openchrome-devel mailing list